@@ -1,11 +1,15 @@
 suppressWarnings(library(lavaan))
 
-latent <- list(visual = paste0("x", 1:3),
-               textual = paste0("x", 4:6),
-               speed = paste0("x", 7:9))
+latent <- list(
+  visual = paste0("x", 1:3),
+  textual = paste0("x", 4:6),
+  speed = paste0("x", 7:9)
+)
 
-regression <- list(ageyr = c("visual", "textual", "speed"),
-                   grade = c("visual", "textual", "speed"))
+regression <- list(
+  ageyr = c("visual", "textual", "speed"),
+  grade = c("visual", "textual", "speed")
+)
 
 HS.model <- write_lavaan(latent = latent, regression = regression)
 
